@@ -24,11 +24,13 @@ class AccessTokenClient(BaseClient):
     grant_type = 'refresh_token'
     path = '/auth/o2/token'
 
-    def __init__(self, refresh_token=None, credentials=None):
+    def __init__(self, refresh_token=None, credentials=None, proxies=None, verify=True):
         self.cred = Credentials(refresh_token, credentials)
+        self.proxies = proxies
+        self.verify = verify
 
     def _request(self, url, data, headers):
-        response = requests.post(url, data=data, headers=headers)
+        response = requests.post(url, data=data, headers=headers, proxies=self.proxies, verify=self.verify)
         response_data = response.json()
         if response.status_code != 200:
             error_message = response_data.get('error_description')
